@@ -1,9 +1,8 @@
-from restfly.endpoint import APIEndpoint
 from box import BoxList
+from restfly.endpoint import APIEndpoint
 
 
 class PostureProfilesAPI(APIEndpoint):
-
     def list_profiles(self):
         """
         Returns a list of all configured posture profiles.
@@ -16,7 +15,7 @@ class PostureProfilesAPI(APIEndpoint):
             ...    pprint(posture_profile)
 
         """
-        return self._get('posture', box=BoxList)
+        return self._get("posture", box=BoxList)
 
     def get_profile(self, profile_id: str):
         """
@@ -34,4 +33,4 @@ class PostureProfilesAPI(APIEndpoint):
 
         """
 
-        return self._get(f'posture/{profile_id}')
+        return self._get(f"posture/{profile_id}")
